@@ -56,18 +56,19 @@ impl DirectorySegment {
             directory, first_block_offset
         );
 
-        let mut segment_file =
-            SegmentFile::open(&segment_path, config.segment_over_allocate_size, tracker)?;
+        let block_size = block.total_size();
+        let segment_alloc_size = config.segment_over_allocate_size.max(block_size as u64);
+
+        let mut segment_file = SegmentFile::open(&segment_path, segment_alloc_size, tracker)?;
         segment_file.write_block(0, block)?;
-        let written_data_size = block.total_size();
 
         Ok(DirectorySegment {
             config,
             segment_path,
             segment_file,
             first_block_offset,
-            next_block_offset: first_block_offset + written_data_size as BlockOffset,
-            next_file_offset: written_data_size,
+            next_block_offset: first_block_offset + block_size as BlockOffset,
+            next_file_offset: block_size,
         })
     }
 
@@ -615,7 +616,7 @@ mod tests {
     #[test]
     fn directory_segment_create_and_open() -> anyhow::Result<()> {
         let local_node = LocalNode::generate();
-        let cell = FullCell::generate(local_node);
+        let cell = FullCell::generate(local_node)?;
         let dir = tempfile::tempdir()?;
         let tracker = SegmentTracker::new(1);
 
@@ -654,7 +655,7 @@ mod tests {
     #[test]
     fn directory_segment_create_already_exist() -> anyhow::Result<()> {
         let local_node = LocalNode::generate();
-        let cell = FullCell::generate(local_node);
+        let cell = FullCell::generate(local_node)?;
         let dir = tempfile::tempdir()?;
         let tracker = SegmentTracker::new(1);
 
@@ -704,7 +705,7 @@ mod tests {
     #[test]
     fn directory_segment_append_block() -> anyhow::Result<()> {
         let local_node = LocalNode::generate();
-        let cell = FullCell::generate(local_node);
+        let cell = FullCell::generate(local_node)?;
         let dir = tempfile::tempdir()?;
         let tracker = SegmentTracker::new(1);
 
@@ -751,7 +752,7 @@ mod tests {
     #[test]
     fn directory_segment_non_zero_offset_write() -> anyhow::Result<()> {
         let local_node = LocalNode::generate();
-        let cell = FullCell::generate(local_node);
+        let cell = FullCell::generate(local_node)?;
         let dir = tempfile::tempdir()?;
         let config = Default::default();
         let segment_first_block_offset = 1234;
@@ -793,7 +794,7 @@ mod tests {
     #[test]
     fn directory_segment_grow_and_truncate() -> anyhow::Result<()> {
         let local_node = LocalNode::generate();
-        let cell = FullCell::generate(local_node);
+        let cell = FullCell::generate(local_node)?;
         let config = DirectoryChainStoreConfig {
             segment_over_allocate_size: 100_000,
             ..Default::default()
@@ -831,7 +832,7 @@ mod tests {
     #[test]
     fn directory_segment_truncate_from_segment() -> anyhow::Result<()> {
         let local_node = LocalNode::generate();
-        let cell = FullCell::generate(local_node);
+        let cell = FullCell::generate(local_node)?;
         let dir = tempfile::tempdir()?;
         let config = DirectoryChainStoreConfig {
             segment_over_allocate_size: 100_000,
@@ -886,7 +887,7 @@ mod tests {
     #[test]
     fn segment_file_mmap_transition() -> anyhow::Result<()> {
         let local_node = LocalNode::generate();
-        let cell = FullCell::generate(local_node);
+        let cell = FullCell::generate(local_node)?;
         let config = DirectoryChainStoreConfig {
             segment_over_allocate_size: 100_000,
             ..Default::default()
